@@ -9,7 +9,7 @@ from manifestoo_core.odoo_series import (
 from .common import mock_addons_set
 
 
-def test_detect_from_version():
+def test_detect_from_version() -> None:
     assert detect_from_addon_version("1.0.0") is None
     assert detect_from_addon_version("1.0.0.0.0.0") is None
     assert detect_from_addon_version("8.0.1") is None
@@ -18,7 +18,7 @@ def test_detect_from_version():
     assert detect_from_addon_version("14.0.1.0.0.1") == OdooSeries.v14_0
 
 
-def test_detect_none():
+def test_detect_none() -> None:
     addons_set = mock_addons_set(
         {
             "a": {"version": "1.0.0"},
@@ -28,7 +28,7 @@ def test_detect_none():
     assert detect_from_addons_set(addons_set) == set()
 
 
-def test_detect_one():
+def test_detect_one() -> None:
     addons_set = mock_addons_set(
         {
             "a": {"version": "1.0.0"},
@@ -38,7 +38,7 @@ def test_detect_one():
     assert detect_from_addons_set(addons_set) == {OdooSeries.v12_0}
 
 
-def test_detect_ambiguous():
+def test_detect_ambiguous() -> None:
     addons_set = mock_addons_set(
         {
             "a": {"version": "13.0.1.0.0"},
@@ -48,10 +48,10 @@ def test_detect_ambiguous():
     assert detect_from_addons_set(addons_set) == {OdooSeries.v12_0, OdooSeries.v13_0}
 
 
-def test_series_from_str():
+def test_series_from_str() -> None:
     assert OdooSeries("10.0") == OdooSeries.v10_0
 
 
-def test_unknown_series_from_str():
+def test_unknown_series_from_str() -> None:
     with pytest.raises(ValueError):
         OdooSeries("45.0")
